yt Overview
===========

yt is a toolkit designed to analyze, manage and plot adaptive mesh refinement
data from the Enzo code.

Contents:

.. toctree::
   :maxdepth: 2

   intro
   getting_started
   quick_guide/index
   tutorial/index
   cookbook/index
   extending/index
   faq
   modules/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
